@@ -27,11 +27,12 @@ def AutoDetectSubtitle(pathvideofile, sub_list=None):
     for ext in subtitlefile.SUBTITLES_EXT:
         possiblefilenamesrt = filename1_noextension + "." + ext
         if sub_list:
-            print sub_list
+            #print sub_list
             try:
                 # check if subtitle is in our list
-                sub_list.index(possiblefilenamesrt)
-                return possiblefilenamesrt
+                if isinstance(sub_list, list):
+                    sub_list.index(possiblefilenamesrt)
+                    return possiblefilenamesrt
             except ValueError, e:
                 log.debug(e)
             except AttributeError, e:
@@ -152,6 +153,7 @@ def subtitle_name_gen(video_filename, extension=".srt"):
     video_name = ""
     sub_name = ""
     if isinstance(video_filename, str):
+        video_filename = video_filename.lower()
         if get_extension(video_filename) in videofile.VIDEOS_EXT:
             video_name = without_extension(video_filename)
     elif isinstance(video_filename, videofile):
