@@ -135,6 +135,7 @@ class Main(QObject, Ui_MainWindow):
         self.folderView.scrollTo(model.index(lastDir.toString()))
         QObject.connect(self.folderView, SIGNAL("clicked(QModelIndex)"),  self.onFolderTreeClicked)
         QObject.connect(self.buttonFind, SIGNAL("clicked(bool)"), self.onButtonFind)
+        QObject.connect(self.buttonRefresh, SIGNAL("clicked(bool)"), self.onButtonRefresh)
 
         #SETTING UP SEARCH_VIDEO_VIEW
         self.videoModel = VideoTreeModel(window)
@@ -287,6 +288,22 @@ class Main(QObject, Ui_MainWindow):
                         self.SearchVideos(options.videofile)
                 else:
                         QMessageBox.about(self.window,_("Error"),_("Unable to find %s") % options.videofile)
+                        
+    def onButtonRefresh(self):
+        settings = QSettings()
+        lastDir = settings.value("mainwindow/workingDirectory", QVariant(QDir.homePath()))
+        path = QDir(lastDir.toString())
+        window = QMainWindow()
+        self.window = window
+        model = QDirModel(window)
+        model.setFilter(QDir.AllDirs|QDir.NoDotAndDotDot)
+        self.folderView.setModel(model)
+        
+        self.folderView.show()
+                
+        while True:
+            self.folderView.expand(model.index(path.absolutePath()))
+            if not path.cdUp(): break
 
     def SetupInterfaceLang(self):
         if platform.system() == "Linux":
@@ -971,7 +988,6 @@ class Main(QObject, Ui_MainWindow):
                 params.append(param)
 
             params.insert(0,'"' + programPath+'"' )
-            print params
             log.info("Running this command:\n%s %s" % (programPath, params))
             try:
                 os.spawnvpe(os.P_NOWAIT, programPath,params, os.environ)
@@ -994,6 +1010,8 @@ class Main(QObject, Ui_MainWindow):
            subFileName = without_extension(video.getFileName()) +"." + sub_extension
         elif optionSubtitleName == QVariant("SAME_VIDEOPLUSLANG"):
            subFileName = without_extension(video.getFileName()) +"." +subtitle.getLanguageXXX() +"." + sub_extension
+        elif optionSubtitleName == QVariant("SAME_VIDEOPLUSLANGANDUPLOADER"):
+           subFileName = without_extension(video.getFileName()) +"." +subtitle.getLanguageXXX() +"." +subtitle.getUploader()+"." + sub_extension
         elif optionSubtitleName == QVariant("SAME_ONLINE"):
            subFileName = subtitle.getFileName()
 
@@ -1008,8 +1026,7 @@ class Main(QObject, Ui_MainWindow):
         elif optionWhereToDownload == QVariant("SAME_FOLDER"):
             folderPath = video.getFolderPath()
             dir = QDir(QString(folderPath))
-            #downloadFullPath = dir.filePath(QString(subFileName)).__str__()
-            downloadFullPath = os.path.join(folderPath, subFileName).decode('utf8')
+            downloadFullPath = os.path.join(folderPath, subFileName)
             log.debug("Downloading to: %r"% downloadFullPath)
         elif optionWhereToDownload == QVariant("PREDEFINED_FOLDER"):
             folderPath = settings.value("options/whereToDownloadFolder", QVariant("")).toString()
@@ -1496,6 +1513,7 @@ class Main(QObject, Ui_MainWindow):
     def onButtonSearchByTitle(self):
         if len(self.movieNameText.text()) == 0:
             QMessageBox.about(self.window,_("Info"),_("You must enter at least one character in movie name"))
+            
         else:
             self.buttonSearchByName.setEnabled(False)
             self.status_progress = QProgressDialog(_("Searching..."), "&Abort", 0, 0, self.window)
@@ -1515,6 +1533,9 @@ class Main(QObject, Ui_MainWindow):
             self.progress(0)
             #This should be in a thread to be able to Cancel
             movies = s.search_movie(search_text,'all')
+            if movies == 2:
+                QMessageBox.about(self.window,_("Info"),_("The server is momentarily unavailable. Please try later."))
+                sys.exit(1)
             self.moviesModel.setMovies(movies, selectedLanguageXXX)
             if len(movies) == 1:
                 self.moviesView.expandAll()
@@ -1594,12 +1615,19 @@ class Main(QObject, Ui_MainWindow):
         for i, sub in enumerate(subs):
             if not self.status_progress.wasCanceled(): #Skip rest of loop if Abort was pushed in progress bar
 
-                url = sub.getExtraInfo("downloadLink")
+                try:            
+                    url = sub.getExtraInfo("downloadLink")
+                except:
+                    url = Link().OneLink(0)
 #                webbrowser.open( url, new=2, autoraise=1)
                 zipFileID = re.search("(\/.*\/)(.*)\Z", url).group(2)
                 zipFileName = "sub-" + zipFileID + ".zip"
-
-                zipDestFile = os.path.join(str(zipDestDir), zipFileName)
+                zipDestDir = str(zipDestDir.toUtf8()).decode(sys.getfilesystemencoding())
+                
+                try:
+                    zipDestFile = os.path.join(zipDestDir, zipFileName).decode(sys.getfilesystemencoding())
+                except:
+                    zipDestFile = (zipDestDir + '/' + zipFileName)
 
                 log.debug("About to download %s to %s" % (url, zipDestFile))
                 count += percentage
@@ -1625,6 +1653,8 @@ class Main(QObject, Ui_MainWindow):
                 # Only try unziping if download was succesful
                 if dlOK:
                     try:
+                        zipDestFile = zipDestFile.encode("utf-8")
+                        zipDestDir = zipDestDir.encode("utf-8")
                         zipf = zipfile.ZipFile(zipDestFile, "r")
                         for fname in zipf.namelist():
                             if (fname.endswith('/')) or (fname.endswith('\\')):
@@ -1664,6 +1694,11 @@ class Main(QObject, Ui_MainWindow):
             #print temp_movie
             try:
                 movie.subtitles = temp_movie[0].subtitles
+            except IndexError:
+                QMessageBox.about(self.window,_("Info"),_("This is a TV series and it cannot be handled."))
+                self.status_progress.close()
+                self.status_progress.destroy()
+                return
             except AttributeError:
                 # this means only one subtitle was returned
                 movie.subtitles = [temp_movie[1]]
@@ -1676,7 +1711,7 @@ class Main(QObject, Ui_MainWindow):
 
 def onUpgradeDetected():
         QMessageBox.about(self.window,_("A new version of SubDownloader has been released."))
-
+ 
 def main(options):
     log.debug("Building main dialog")
 #    app = QApplication(sys.argv)
