@@ -5,6 +5,12 @@ import logging
 import urllib2
 from xml.dom import minidom
 import xml.parsers.expat
+import sys
+from PyQt4.QtCore import *
+from PyQt4.QtGui import *
+
+OnlyLink = ''
+FilmLink = ''
 
 try:
     from modules import subtitlefile
@@ -12,6 +18,15 @@ except ImportError:
     import sys, os
     sys.path.append(os.path.dirname(os.path.dirname(os.getcwd())))
     from modules import subtitlefile
+
+class Link:
+    def OneLink(self, OnlyLink):
+        global FilmLink
+        if OnlyLink == 0:
+            return FilmLink
+        elif OnlyLink != 0:
+            FilmLink = OnlyLink
+            return        
     
 class Movie(object):
     def __init__(self, movieInfo):
@@ -49,7 +64,12 @@ class SearchByName(object):
         else:
             moviename = moviename.replace(" ","%20")
             xml_url = "http://www.opensubtitles.com/en/search2/sublanguageid-%s/moviename-%s/xml"% (sublanguageid, moviename)
-        xml_page = urllib2.urlopen(xml_url)
+            
+        try:    
+            xml_page = urllib2.urlopen(xml_url)
+        except:
+            return(2)
+            
         try:
             self.log.debug("Getting data from '%s'"% xml_url)
             search = self.parse_results(xml_page.read())
@@ -93,6 +113,7 @@ class SearchByName(object):
         if not data:
             return []
         # catch subtitle information
+        
         for entry in data:
             sub_obj = subtitlefile.SubtitleFile(online=True)
             sub = {}
@@ -128,10 +149,11 @@ class SearchByName(object):
                 sub_obj._uploader = sub['UserNickName']
             if entry.getElementsByTagName('LanguageName') and entry.getElementsByTagName('LanguageName')[0].firstChild:
                 sub['LanguageName'] = entry.getElementsByTagName('LanguageName')[0].firstChild.data
-                sub_obj.setLanguageXX(entry.getElementsByTagName('LanguageName')[0].getAttribute('ISO639'))
+                sub_obj.setLanguageXX(entry.getElementsByTagName('LanguageName')[0].getAttribute('ISO639'))             
             if entry.getElementsByTagName('SubtitleFile'):
                 SubtitleFile = {}
                 _SubtitleFile = entry.getElementsByTagName('SubtitleFile')[0]
+
                 _File = _SubtitleFile.getElementsByTagName('File')[0]
                 SubtitleFile['File'] = {'ID': _SubtitleFile.getElementsByTagName('File')[0].getAttribute('ID'), 
                                                 'SubActualCD': {'SubActualCD':_File.getElementsByTagName('SubActualCD')[0].firstChild.data, 
@@ -139,13 +161,16 @@ class SearchByName(object):
                                                                         'MD5': _File.getElementsByTagName('SubActualCD')[0].getAttribute('MD5'), 
                                                                         'SubFileName': _File.getElementsByTagName('SubActualCD')[0].getAttribute('SubFileName'), 
                                                                         'DownloadLink': _File.getElementsByTagName('SubActualCD')[0].getAttribute('DownloadLink'),  
-                                                                        }, 
-                                                'SubPreview': _File.getElementsByTagName('SubPreview')[0].firstChild.data
+                                                                        }
                                                 }
+                
                 SubtitleFile['Download'] = {'Download': _SubtitleFile.getElementsByTagName('Download')[0].firstChild.data, 
-                                                        'DownloadLink': _SubtitleFile.getElementsByTagName('Download')[0].getAttribute('DownloadLink'),  
+                                                        'DownloadLink': _SubtitleFile.getElementsByTagName('Download')[0].getAttribute('LinkDownloadBundle'),  
                                                         }
                 sub['SubtitleFile'] = SubtitleFile
+                global OnlyLink
+                OnlyLink = _SubtitleFile.getElementsByTagName('Download')[0].getAttribute('LinkDownloadBundle')
+                OnlyLink = ((OnlyLink.replace('dl', 'www')).replace('org/en', 'com')).replace('subb', 'sub')
             if entry.getElementsByTagName('Movie'):
                 _Movie = entry.getElementsByTagName('Movie')[0]
                 #sub['MovieName'] = _Movie.getElementsByTagName('MovieName')[0].firstChild.data
@@ -164,6 +189,7 @@ class SearchByName(object):
                 sub['ReportLink'] = entry.getElementsByTagName('ReportLink')[0].firstChild.data
             # just s shortcut
             sub['DownloadLink'] = sub['SubtitleFile']['File']['SubActualCD']['DownloadLink']
+            Link().OneLink(OnlyLink)
             if sub:
                 subtitle_entries.append(sub)
         return (subtitle_entries, sub_obj)
@@ -182,6 +208,8 @@ class SearchByName(object):
                 }, 
                 ...]
         """
+        
+
         dom = minidom.parseString(raw_xml) #Make the dom from raw xml
         entries=dom.getElementsByTagName('opensubtitles') #Pull out all entry's
         result_entries=[] #Make an empty container to fill up and return
@@ -202,6 +230,9 @@ class SearchByName(object):
             try:
                 sub_obj = subtitlefile.SubtitleFile(online=True)
                 sub = {}
+                
+                if entry.getElementsByTagName('EpisodeName'):
+                    return
                 if entry.getElementsByTagName('IDSubtitle'):
                     sub['IDSubtitle'] = { 'IDSubtitle': entry.getElementsByTagName('IDSubtitle')[0].firstChild.data, 
                                                         'Link': entry.getElementsByTagName('IDSubtitle')[0].getAttribute('Link'), 
@@ -239,6 +270,8 @@ class SearchByName(object):
                     sub['MovieYear'] = entry.getElementsByTagName('MovieYear')[0].firstChild.data
                 if entry.getElementsByTagName('MovieImdbRating') and entry.getElementsByTagName('MovieImdbRating')[0].firstChild:
                     sub['MovieImdbRating'] = entry.getElementsByTagName('MovieImdbRating')[0].firstChild.data
+                elif not entry.getElementsByTagName('MovieImdbRating')[0].firstChild:
+                    sub['MovieImdbRating'] = 0
                 if entry.getElementsByTagName('MovieImdbID') and entry.getElementsByTagName('MovieImdbID')[0].firstChild:
                     sub['MovieImdbID'] = entry.getElementsByTagName('MovieImdbID')[0].firstChild.data
                 if entry.getElementsByTagName('SubAuthorComment'):
